==> migratedb-core-0.3.0-sources.jar: migratedb/v1/core/internal/database/redshift/RedshiftTable.java <==
/*
 * Copyright (C) Red Gate Software Ltd 2010-2021
 * Copyright 2022 The MigrateDB contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package migratedb.v1.core.internal.database.redshift;

import migratedb.v1.core.api.internal.jdbc.JdbcTemplate;
import migratedb.v1.core.internal.database.base.BaseTable;

import java.sql.SQLException;
import java.util.Locale;

/**
 * Redshift-specific table.
 */
public class RedshiftTable extends BaseTable<RedshiftDatabase, RedshiftSchema> {
    /**
     * Creates a new Redshift table.
     *
     * @param jdbcTemplate The Jdbc Template for communicating with the DB.
     * @param database     The database-specific support.
     * @param schema       The schema this table lives in.
     * @param name         The name of the table.
     */
    RedshiftTable(JdbcTemplate jdbcTemplate, RedshiftDatabase database, RedshiftSchema schema, String name) {
        super(jdbcTemplate, database, schema, name);
    }

    @Override
    protected void doDrop() throws SQLException {
        jdbcTemplate.execute("DROP TABLE " + database.quote(schema.getName(), name) + " CASCADE");
    }

    @Override
    protected boolean doExists() throws SQLException {
        return jdbcTemplate.queryForBoolean("SELECT EXISTS (\n" +
                                            "  SELECT 1\n" +
                                            "  FROM   pg_catalog.pg_class c\n" +
                                            "  JOIN   pg_catalog.pg_namespace n ON n.oid = c.relnamespace\n" +
                                            "  WHERE  n.nspname = ?\n" +
                                            "  AND    c.relname = ?\n" +
                                            "  AND    c.relkind = 'r'\n" + // only tables
                                            ")",
                                            schema.getName(),
                name.toLowerCase(Locale.ROOT)
                                            // Redshift table names are case-insensitive and always in lowercase in pg_class.
        );
    }

    @Override
    protected void doLock() throws SQLException {
        jdbcTemplate.execute("DELETE FROM " + this + " WHERE FALSE");
    }
}

==> migratedb-core-1.5.0-sources.jar: migratedb/v1/core/internal/database/redshift/RedshiftTable.java <==
/*
 * Copyright (C) Red Gate Software Ltd 2010-2021
 * Copyright 2022-2024 The MigrateDB contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package migratedb.v1.core.internal.database.redshift;

import migratedb.v1.core.api.internal.jdbc.JdbcTemplate;
import migratedb.v1.core.internal.database.base.BaseTable;

import java.sql.SQLException;
import java.util.Locale;

/**
 * Redshift-specific table.
 */
public class RedshiftTable extends BaseTable {
    /**
     * Creates a new Redshift table.
     *
     * @param jdbcTemplate The Jdbc Template for communicating with the DB.
     * @param database     The database-specific support.
     * @param schema       The schema this table lives in.
     * @param name         The name of the table.
     */
    RedshiftTable(JdbcTemplate jdbcTemplate, RedshiftDatabase database, RedshiftSchema schema, String name) {
        super(jdbcTemplate, database, schema, name);
    }

    @Override
    protected boolean doExists() throws SQLException {
        return jdbcTemplate.queryForBoolean("SELECT EXISTS (\n" +
                                            "  SELECT 1\n" +
                                            "  FROM   pg_catalog.pg_class c\n" +
                                            "  JOIN   pg_catalog.pg_namespace n ON n.oid = c.relnamespace\n" +
                                            "  WHERE  n.nspname = ?\n" +
                                            "  AND    c.relname = ?\n" +
                                            "  AND    c.relkind = 'r'\n" + // only tables
                                            ")",
                                            getSchema().getName(),
                getName().toLowerCase(Locale.ROOT)
                                            // Redshift table names are case-insensitive and always in lowercase in pg_class.
        );
    }

    @Override
    protected void doLock() throws SQLException {
        jdbcTemplate.execute("DELETE FROM " + this + " WHERE FALSE");
    }
}
